document.addEventListener('DOMContentLoaded', function () {
  const node = document.querySelector('.node');
  const modal = document.querySelector('#text-clarity-checker');
  if (!node || !modal) return;

  const metrics = {
    textLength: 0,
    imageCount: 0,
    decorativeImageCount: 0,
    paragraphCount: 0,
    averageParagraphLength: 0,
    readingTime: 0,
    hasH1: false,
    hasValidHeadingStructure: true,
    backgroundImageCount: 0,
    elementCount: 0,
    internalLinkCount: 0,
    externalLinkCount: 0,
    headingDepth: 0,
    estimatedLoadTime: 0
  };

  const textContent = node.textContent.trim();
  metrics.textLength = textContent.split(/\s+/).length;
  metrics.readingTime = Math.ceil(metrics.textLength / 200);

  const images = Array.from(node.getElementsByTagName('img'));
  metrics.imageCount = images.length;

  images.forEach(img => {
    const altText = img.alt.trim();
    if (!altText || altText.split(/\s+/).length < 5) {
      metrics.decorativeImageCount++;
      metrics.readingTime += 2;
    } else {
      metrics.readingTime += Math.ceil(altText.split(/\s+/).length / 200);
    }
  });

  const allElements = node.querySelectorAll('*');
  allElements.forEach(element => {
    const style = window.getComputedStyle(element);
    if (style.backgroundImage !== 'none') {
      metrics.backgroundImageCount++;
    }
  });

  metrics.elementCount = allElements.length;
  metrics.paragraphCount = node.getElementsByTagName('p').length;
  metrics.hasH1 = !!node.querySelector('h1');

  const headings = Array.from(node.querySelectorAll('h1, h2, h3, h4, h5, h6'));
  metrics.hasValidHeadingStructure = checkHeadingStructure(headings);
  if (headings.length > 0) {
    metrics.headingDepth = Math.max(...headings.map(h => parseInt(h.tagName.replace('H', ''), 10)));
  }

  const paragraphs = Array.from(node.getElementsByTagName('p'));
  if (paragraphs.length > 0) {
    const totalParagraphLength = paragraphs.reduce((sum, p) => sum + p.textContent.trim().split(/\s+/).length, 0);
    metrics.averageParagraphLength = totalParagraphLength / paragraphs.length;
  }

  const links = Array.from(node.getElementsByTagName('a'));
  links.forEach(link => {
    const href = link.getAttribute('href');
    if (href && href.startsWith(window.location.origin)) {
      metrics.internalLinkCount++;
    } else if (href && href.startsWith('http')) {
      metrics.externalLinkCount++;
    }
  });

  metrics.estimatedLoadTime = (metrics.imageCount * 0.5) + (metrics.elementCount * 0.01);

  const score = calculateUXScore(metrics);

  document.querySelector('.metric-text').textContent += ` ${metrics.textLength}`;
  document.querySelector('.metric-reading').textContent += ` ${metrics.readingTime} min`;
  document.querySelector('.metric-img').textContent += ` ${metrics.imageCount}`;
  document.querySelector('.metric-decorative-img').textContent += ` ${metrics.decorativeImageCount}`;
  document.querySelector('.metric-background-img').textContent += ` ${metrics.backgroundImageCount}`;
  document.querySelector('.metric-element').textContent += ` ${metrics.elementCount}`;
  document.querySelector('.metric-paragraph').textContent += ` ${metrics.paragraphCount}`;
  document.querySelector('.metric-paragraph-len').textContent += ` ${metrics.averageParagraphLength.toFixed(2)}`;
  document.querySelector('.metric-valid-title').textContent += ` ${metrics.hasValidHeadingStructure ? 'Yes' : 'No'}`;
  document.querySelector('.metric-heading-depth').textContent += ` ${metrics.headingDepth}`;
  document.querySelector('.metric-internal-links').textContent += ` ${metrics.internalLinkCount}`;
  document.querySelector('.metric-external-links').textContent += ` ${metrics.externalLinkCount}`;
  document.querySelector('.metric-load-time').textContent += ` ${metrics.estimatedLoadTime.toFixed(2)} sec`;
  document.querySelector('#score').textContent += ` ${score}`;
  updateScoreCircle(score);
  const score_pastille = document.querySelector('#score-pastille');
  score_pastille.textContent += ` ${score}`;
  score_pastille.addEventListener('click', e => {
    if ((modal.classList.contains('show'))) {
      modal.classList.remove('show');
      return;
    }
    modal.classList.add('show');
  });

  function calculateUXScore(metrics) {
    let score = 100;

    if (metrics.textLength > 1000) score -= 10;
    if (metrics.imageCount < 1) score -= 15;
    if (metrics.paragraphCount < 3) score -= 10;
    if (metrics.averageParagraphLength > 80) score -= 10;
    if (!metrics.hasValidHeadingStructure) score -= 20;
    if (metrics.elementCount > 50) score -= 10;
    if (metrics.headingDepth > 4) score -= 5;
    if (metrics.externalLinkCount > metrics.internalLinkCount) score -= 5;

    return Math.max(0, score);
  }

  function checkHeadingStructure(headings) {
    if (headings.length === 0) return true;

    let lastLevel = 0;
    for (const heading of headings) {
      const level = parseInt(heading.tagName.replace('H', ''), 10);
      if (lastLevel && level > lastLevel + 1) {
        return false;
      }
      lastLevel = level;
    }
    return true;
  }
  function updateScoreCircle(score) {
    const scoreCircle = document.querySelector('.score-circle');
    const startColor = { r: 193, g: 26, b: 14 };
    const endColor = { r: 6, g: 169, b: 44 };

    const r = Math.floor(startColor.r + (endColor.r - startColor.r) * (score / 100));
    const g = Math.floor(startColor.g + (endColor.g - startColor.g) * (score / 100));
    const b = Math.floor(startColor.b + (endColor.b - startColor.b) * (score / 100));

    scoreCircle.style.backgroundColor = `rgb(${r}, ${g}, ${b})`;
  }
});
